<?php

/*
 * ParseWowhead
 * started: 31/05/2007
 *
 * author: Frank Matheron
 * email: fenuzz@gmail.com
 * description: create itemstats tooltips using wowhead
 *
 * version: 0.3.2
 *
 */

include_once(dirname(__FILE__) . '/../config.php');
include_once(dirname(__FILE__) . '/../config_armory.php');
include_once(dirname(__FILE__) . '/xmltoarray.inc.php');
include_once(dirname(__FILE__) . '/urlreader.php');
include_once(dirname(__FILE__) . '/download_file.php');

// The main interface to the Armory parser
class ParseArmory
{
        function arrayToHtml ($array) {
          $str = "<div class=\"armory_".$array["name"]."\">";
          if (sizeof($array["attr"])>0) {
            foreach ($array["attr"] as $key => $val) {
              $str .="<div class=\"armory_".$array["name"]."_".$key."\">".$val."</div>";
            }
          }
          $str.=$array["data"];
          if (sizeof($array["child"])>0) {
            foreach ($array["child"] as $child)
               $str.=$this->arrayToHtml($child);
          }
          $str.="</div>";
          return $str;
        }
	// Attempts to retrieve data for the specified item from Wowhead
	function getItem($name,$language='en')
    	{
		

		// Ignore blank names.
		$name = trim($name);
		if (empty($name)) { return null; }
		
		$item = array('name' => $name);

		// remove extra spaces (vB is known to add them)
		$fixed_name = implode(' ', preg_split ("/[\s\+]+/", urldecode($name)));
	
		// encode the name so it can be used to build the url
		$encoded_name = utf8_encode($fixed_name);//rawurlencode($fixed_name);
		$encoded_name = str_replace('+' , '%20' , $encoded_name);
               $encoded_name = str_replace(' ' , '%20' , $encoded_name);

		// Perform the search, and retrieve the result
		unset($xml_parser); // unset $xml_parser to prevent warnings on PHP4x
		$xml_parser = new XmlToArray();
		$xml_search_data = utf8_decode(itemstats_read_url('http://armory.worldofwarcraft.com/search.xml?searchType=items&searchQuery=' . $encoded_name, $language));
		if (debug_mode == true) {
                    echo "Search on the Armory site : " . $name." in the ".$language." language : http://armory.worldofwarcraft.com/search.xml?searchType=items&searchQuery=" . $encoded_name."<br/>";
                    var_dump($xml_search_data);
                }
                if (strpos($xml_search_data,'<items>') === false) return $item;
		$xml_search_data=substr($xml_search_data,strpos($xml_search_data,'<items>'));
                $xml_search_data=substr($xml_search_data,0,strpos($xml_search_data,'</items>')+8);
                $result = $xml_parser->parse($xml_search_data);


		// find the ITEMS section in the xml file, if its not there we did not find _anything_
		$items_idx = -1;
		$i = 0;
		foreach($result[0]['child'] as $category) {
			if ($category['name'] == 'ITEM') {
				$items_idx = $i;
				break;
			}
			$i++;
		}

		// our search found one or more items
		if ($items_idx != -1) {
			$found_item = $result[0]['child'][$items_idx];
			$item_id = -1;
			
                        $item_id = $found_item['attr']['ID'];
			$found_name = $found_item['attr']['NAME'];

			if ($item_id != -1) {
				// we found the item in the results, retrieve the item data using its item id
				return $this->getItemId($item_id, $found_name,$language);
			}
		}
		
		unset($item['link']);
		return $item;
	}

	// Attempts to retrieve data for the specified item from Wowhead by its wowhead itemid
	function getItemId($item_id, $name = '',$language='en')
	{
		$item = array('id' => $item_id);

                // retrieve the item data
		unset($xml_parser); // unset $xml_parser to prevent warnings on PHP4x
		$xml_parser = new XmlToArray();
		$xml_item_data = utf8_decode(itemstats_read_url('http://armory.worldofwarcraft.com/item-tooltip.xml?i=' . $item_id, $language));
		$item_data = $xml_parser->parse($xml_item_data);
		
		if (debug_mode == true) {
                    echo "Search on the Armory site : " . $item_id." in the ".$language." language<br/>";
                //    var_dump($item_data);
                }

		if (sizeof($item_data) == 0) {
			// error, probably an invalid item id
			unset($item['link']);
			return $item;
		}
		// apparantly weve got valid item data
		
		// create an array of item properties
		$properties = array();
		foreach($item_data[0]['child'][0]['child'][0]['child'] as $property) {
			$properties[$property['name']]['data'] = $property['data'];
			$properties[$property['name']]['attr'] = $property['attr'];
			if (sizeof($property['child'])) {
                           foreach($property['child'] as $k=>$p) {
                             $properties[$property['name']."_".$p['name'].$k]['data'] = $p['data'];
			     $properties[$property['name']."_".$p['name'].$k]['attr'] = $p['attr'];
			     if (sizeof($p['child'])) {
                                 foreach($p['child'] as $q) {
                                   $properties[$property['name']."_".$p['name'].$k."_".$q['name']]['data'] = $q['data'];
      			           $properties[$property['name']."_".$p['name'].$k."_".$q['name']]['attr'] = $q['attr'];
                                 }
                              }
                           }
                        }
		}

		// set item data
		if ($name != '') {
			$item['name'] = $name;
		} else {
			$item['name'] = $properties['NAME']['data'];
		}
		$item['lang'] = $language;
		$item['link'] = 'http://armory.wow-europe.com/item-info.xml?i='.$item_id; // wowhead url to the item
		$item['icon'] = $properties['ICON']['data']; // icon filename without an extension

		// if download icons is enabled, download the icon
		if (DOWNLOAD_ICONS) {
			if (!$this->downloadIcon($item['icon'])) {
				// failed to download the icon, use default
				$item['icon'] = DEFAULT_ICON;
			}
		}
		// set the item color based on the item quality
		switch ($properties['OVERALLQUALITYID']['data']) {
			case 0:
				$item['color'] = 'greyname';
				break;
			case 1:
				$item['color'] = 'whitename';
				break;
			case 2:
				$item['color'] = 'greenname';
				break;
			case 3:
				$item['color'] = 'bluename';
				break;
			case 4:
				$item['color'] = 'purplename';
				break;
			case 5:
				$item['color'] = 'orangename';
				break;
			case 6:
				$item['color'] = 'redname';
				break;
			default:
				$item['color'] = 'greyname';
				break;
		}
		
		$properties['HTMLTOOLTIP']['data'] = "<table><tr><td><b class=\"q".$properties['OVERALLQUALITYID']['data']."\">".$item['name']."</b><br/>";
		switch($properties['BONDING']['data']) {
                   case '1':  $properties['HTMLTOOLTIP']['data'] .= "Li quand ramass<br/>";break;
                   case '4': $properties['HTMLTOOLTIP']['data'] .= "Item de qute<br/>";break;
                   default : $properties['HTMLTOOLTIP']['data'] .= "Li quand quip<br/>";
                }
		if ($properties['MAXCOUNT']['data']) {
                   $properties['HTMLTOOLTIP']['data'] .= "Unique<br/>";
                }
                $slots = array (
                	1 => "Tte",
                	2 => "Cou",
                	3 => "Epaules",
                	4 => "4 ?",
                	5 => "Torse",
                	6 => "Taille",
                	7 => "Jambes",
                	8 => "Pieds",
                	9 => "Poignets",
                	10 => "Mains",
                	11 => "Doigt",
                	12 => "Bijou",
                	13 => "Une main",
                	14 => "Bouclier",
                	15 => "Arc",
                	16 => "Dos",
                	17 => "Deux mains",
                	18 => "Sac",
                	19 => "19 ?",
                	20 => "Torse",
                	21 => "Main droite",
                	22 => "Main gauche",
                	23 => "Tenu en main gauche",
                	24 => "24 ?",
                	25 => "Arme de jet",
                	26 => "Arme  distance",
                	27 => "27 ?",
                	28 => "Relique",
                );
                if ((int)$properties['EQUIPDATA_INVENTORYTYPE0']['data'] > 0)
                                $properties['HTMLTOOLTIP']['data'].= "<table><tbody><tr><td>".$slots[$properties['EQUIPDATA_INVENTORYTYPE0']['data']]."</td><th>".$properties['EQUIPDATA_SUBCLASSNAME1']['data']."</th></tr></tbody></table>";
                                
                if ($properties['DAMAGEDATA']['data']) {
                    $damage=array(0=>"", 1=>"(Sacr)", 2=>"(Feu)", 3=>"(Nature)", 4=>"Givre", 5=>"(Ombre)", 6=>"(Arcane)");
                    $properties['HTMLTOOLTIP']['data'].= "<table><tbody><tr><td>".$properties['DAMAGEDATA_DAMAGE0_MIN']['data']." - ".$properties['DAMAGEDATA_DAMAGE0_MAX']['data']." Dgts ".$damage[$properties['DAMAGEDATA_DAMAGE0_TYPE']['data']]."</td>";
                    $properties['HTMLTOOLTIP']['data'].= "<th>Vitesse : ".$properties['DAMAGEDATA_SPEED1']['data']."</th></tr></tbody></table>";
                    $properties['HTMLTOOLTIP']['data'].= "(".$properties['DAMAGEDATA_DPS2']['data']." dgts par seconde)<br/>";
                }

                if ($properties['REQUIREDSKILL'])
                   $properties['HTMLTOOLTIP']['data'].= $properties['REQUIREDSKILL']['attr']['NAME']." (".$properties['REQUIREDSKILL']['attr']['RANK'].") requis<br/>";
                if ($properties['ARMOR'])
                   $properties['HTMLTOOLTIP']['data'].= "Armure : ".$properties['ARMOR']['data']."<br/>";
                if ($properties['BONUSSTRENGTH']['data']) {
                   $properties['HTMLTOOLTIP']['data'].= (((int)$properties['BONUSSTRENGTH']['data'])>0)?"+":"";
                   $properties['HTMLTOOLTIP']['data'].= (int)$properties['BONUSSTRENGTH']['data'];
                   $properties['HTMLTOOLTIP']['data'].= " Force<br/>";
                }
                if ($properties['BONUSAGILITY']['data']) {
                   $properties['HTMLTOOLTIP']['data'].= (((int)$properties['BONUSAGILITY']['data'])>0)?"+":"";
                   $properties['HTMLTOOLTIP']['data'].= (int)$properties['BONUSAGILITY']['data'];
                   $properties['HTMLTOOLTIP']['data'].= " Agilit<br/>";
                }
                if ($properties['BONUSSTAMINA']['data']) {
                   $properties['HTMLTOOLTIP']['data'].= (((int)$properties['BONUSSTAMINA']['data'])>0)?"+":"";
                   $properties['HTMLTOOLTIP']['data'].= (int)$properties['BONUSSTAMINA']['data'];
                   $properties['HTMLTOOLTIP']['data'].= " Endurance<br/>";
                }
                if ($properties['BONUSINTELLECT']['data']) {
                   $properties['HTMLTOOLTIP']['data'].= (((int)$properties['BONUSINTELLECT']['data'])>0)?"+":"";
                   $properties['HTMLTOOLTIP']['data'].= (int)$properties['BONUSINTELLECT']['data'];
                   $properties['HTMLTOOLTIP']['data'].= " Intelligence<br/>";
                }

                if ($properties['BONUSSPIRIT']['data']) {
                   $properties['HTMLTOOLTIP']['data'].= (((int)$properties['BONUSSPIRIT']['data'])>0)?"+":"";
                   $properties['HTMLTOOLTIP']['data'].= (int)$properties['BONUSSPIRIT']['data'];
                   $properties['HTMLTOOLTIP']['data'].= " Esprit<br/>";
                }
                if ($properties['SOCKETDATA']) {
                   for ($i=0;$i<3;$i++) {
                       if ($properties['SOCKETDATA_SOCKET'.$i]) {
                         $properties['HTMLTOOLTIP']['data'].= "<span class=\"socket-";

                         switch($properties['SOCKETDATA_SOCKET'.$i]['attr']["COLOR"]) {
                           case 'Blue': $properties['HTMLTOOLTIP']['data'].= "blue q0\">Chsse bleue";break;
                           case 'Red': $properties['HTMLTOOLTIP']['data'].= "red q0\">Chsse rouge";break;
                           case 'Yellow':$properties['HTMLTOOLTIP']['data'].= "yellow q0\">Chsse jaune";break;
                           case 'Meta': $properties['HTMLTOOLTIP']['data'].= "meta q0\">Mta-chsse";break;
                         }
                         $properties['HTMLTOOLTIP']['data'].= "</span><br/>";
                       } else break;
                   }
                   $properties['HTMLTOOLTIP']['data'].="<span class=\"q0\">Bonus de sertissage : ".$properties['SOCKETDATA_SOCKETMATCHENCHANT'.$i]['data']."</span><br/>";
                }
                
                if ($properties['DURABILITY']) {
                  $properties['HTMLTOOLTIP']['data'] .= "Durabilit : ".$properties['DURABILITY']['attr']['CURRENT']." / ".$properties['DURABILITY']['attr']['MAX']."<br/>";
                }
                if ($properties['ALLOWABLECLASSES']) {
                    $properties['HTMLTOOLTIP']['data'] .= "Classes : ";

                    for ($i=0;$i<10;$i++) {
                         if ($properties['ALLOWABLECLASSES_CLASS'.$i]) {
                             if ($i>0) $properties['HTMLTOOLTIP']['data'] .= ", ";
                             $properties['HTMLTOOLTIP']['data'] .= $properties['ALLOWABLECLASSES_CLASS'.$i]['data'];
                         } else {
                            $properties['HTMLTOOLTIP']['data'] .= "<br/>";
                            break;
                         }
                    }
                }
                if ($properties['STARTQUESTID']) {
                      $properties['HTMLTOOLTIP']['data'] .= "<a href=\"http://www.wowhead.com/?quest=".$properties['STARTQUESTID']['data']."\">Cet objet permet de lancer une qute</a><br/>";
                }


                if ($properties['REQUIREDLEVEL']) {
                    $properties['HTMLTOOLTIP']['data'] .= "Requiert le niveau ".$properties['REQUIREDLEVEL']['data']."<br/>";
                }
                if ($properties['REQUIREDABILITY']) {
                    $properties['HTMLTOOLTIP']['data'] .= "Requiert ".$properties['REQUIREDABILITY']['data']."<br/>";
                }

                $properties['HTMLTOOLTIP']['data'] .="</td></tr></table>";
                $properties['HTMLTOOLTIP']['data'] .="<table><tr><td>";
                
                if ($properties['BONUSDEFENSESKILLRATING']) {
                  $properties['HTMLTOOLTIP']['data'] .= "<span class=\"q2\">Equip : Augmente le score de dfense de ".$properties['BONUSDEFENSESKILLRATING']['data']."</span><br/>";
                }
                if ($properties['BONUSBLOCKRATING']) {
                  $properties['HTMLTOOLTIP']['data'] .= "<span class=\"q2\">Equip : Augmente de ".$properties['BONUSBLOCKRATING']['data']." le score de blocage</span><br/>";
                }
                if ($properties['BONUSCRITSPELLRATING']) {
                  $properties['HTMLTOOLTIP']['data'] .= "<span class=\"q2\">Equip : Augmente de ".$properties['BONUSCRITSPELLRATING']['data']." le score de coup critique des sorts.</span><br/>";
                }
                if ($properties['BONUSHITSPELLRATING']) {
                  $properties['HTMLTOOLTIP']['data'] .= "<span class=\"q2\">Equip : Augmente de ".$properties['BONUSHITSPELLRATING']['data']." le bonus de toucher des sorts.</span><br/>";
                }
                if ($properties['BONUSCRITRATING']) {
                  $properties['HTMLTOOLTIP']['data'] .= "<span class=\"q2\">Equip : Augmente de ".$properties['BONUSCRITRATING']['data']." le score de coup critique.</span><br/>";
                }
                /*if ($properties['BONUSCRITRATING']) {
                  $properties['HTMLTOOLTIP']['data'] .= "<span class=\"q2\">Equip : Augmente de ".$properties['BONUSCRITRATING']['data']." le score de coup critique.</span><br/>";
                }*/
                if ($properties['BONUSHITRATING']) {
                  $properties['HTMLTOOLTIP']['data'] .= "<span class=\"q2\">Equip : Augmente de ".$properties['BONUSHITRATING']['data']." le score de toucher.</span><br/>";
                }


                if ($properties['SPELLDATA']) {
                  for ($i=0;$i<10;$i++) {
                         if ($properties['SPELLDATA_SPELL'.$i]) {
                             $properties['HTMLTOOLTIP']['data'] .= "<span class=\"q2\">";
                             switch ($properties['SPELLDATA_SPELL'.$i.'_TRIGGER']['data']) {
                               case "1" : $properties['HTMLTOOLTIP']['data'] .= "Equip : "; break;
                               case "2" : $properties['HTMLTOOLTIP']['data'] .= "Chances quand vous touchez : "; break;
                               default :  $properties['HTMLTOOLTIP']['data'] .= "Utiliser : ";
                             }
                             $properties['HTMLTOOLTIP']['data'] .= $properties['SPELLDATA_SPELL'.$i.'_DESC']['data']."</span><br/>";
                         } else break;
                    }
                }
                
                if ($properties['SETDATA']) {
                  $properties['HTMLTOOLTIP']['data'] .= "<br/><span class=\"q\">".$properties['SETDATA_NAME0']['data']."</span>";
                  for ($i=1;$i<15;$i++) {
                         if ($properties['SETDATA_ITEM'.$i]) {
                             $properties['HTMLTOOLTIP']['data'] .= "<div class=\"q0 indent\">".$properties['SETDATA_ITEM'.$i]['attr']['NAME']."</div>";
                         } elseif ($properties['SETDATA_SETBONUS'.$i]) {
                           $properties['HTMLTOOLTIP']['data'] .= "<br/><span class=\"q0\">(".$properties['SETDATA_SETBONUS'.$i]['attr']['THRESHOLD'].") : ".$properties['SETDATA_SETBONUS'.$i]['attr']['DESC']."</span>";
                         } else break;
                    }
                }

                if ($properties['DESC']['data']) {
                   $properties['HTMLTOOLTIP']['data'] .= "<span class=\"q\">\"".$properties['DESC']['data']."\"</span><br/>";
                }

                $properties['HTMLTOOLTIP']['data'] .="</td></tr></table>";

		if (debug_mode) {
                  var_dump(strpos($xml_item_data,"<itemTooltip>"+13));
	//	   var_dump($item);
		   var_dump($properties);
		}
		// create the tooltip html
		/*if (substr($properties['HTMLTOOLTIP']['data'], 0, 7) != '<table>') {
			$item['html'] = '*' . $properties['HTMLTOOLTIP']['data'] . '</td></tr></table>';
		} else {
		*/	$item['html'] = $properties['HTMLTOOLTIP']['data'];
		//}
		// remove the width attributes from the tooltips, they mess the tooltip up in IE
		$item['html'] = str_replace(' width="100%"', '', $item['html']);
		// tooltip title/item name links to its wowhead page
		$item['html'] = str_replace($item['name'], '<a href=\'' . $item['link'] . '\' target=\'_new\'>' . $properties['NAME']['data'] . '</a>', $item['html']);
		// add escape slashes
		$item['html'] = str_replace('"', '\'', $item['html']);

                /*$item['html'] = preg_replace('/<a(.*?)>/', '', $item['html']);
                $item['html'] = str_replace('</a>', '', $item['html']);
		*/// place the tooltip content html into the tooltip template
		$template_html = trim(file_get_contents(dirname(__FILE__) . '/../templates/' . WOWHEAD_TEMPLATE));
		$item['html'] = str_replace('{ITEM_HTML}', $item['html'], $template_html);


		return $item;	
	}

	// downloads an icon
	function downloadIcon($iconname) {
		if (DOWNLOAD_ICONS) {
			if (file_exists(LOCAL_ICON_STORE_PATH . $iconname . ICON_EXTENSION)) {
				// file already exists, dont download
				return true; // return true, the icon is ready to use
			} else {
				// the icon is not available, attempt to download
				return download_file(REMOTE_ICON_STORE_PATH . $iconname . ICON_EXTENSION, LOCAL_ICON_STORE_PATH . $iconname . ICON_EXTENSION);
			}
		}
		return false;
	}

	// Cleans up resources used by this object.
	function close() {}
}

?>