<?php

/* 
 * Itemstats update script
 * started: 31/05/2007
 *
 * author: Frank Matheron
 * email: fenuzz@gmail.com
 * description: simple script that updates all your cached item tooltips
 * usage: set the correct path to your itemstats root dir and run this script 
 *
 * version: 0.2.3
 * history: 0.2.3 (2/06/2007)
 *		- fixed the 'Cannot modify header information' bug
 *	    0.2.2 (1/06/2007)
 *		- fixed inaccurate progress display and skipping of items when nearing 100%
 *	    0.2.1 (1/06/2007)
 *		- no longer uses eqdkp
 *	    0.2.0 (1/06/2007) 	
 *		- updates all items in your item_cache table
 *              - progress indicator added   
 *          0.1.0 (31/05/2007)	
 *		- updates all itemstats tooltips for the items dropped in your dkp system
 *
 */

global $MAIN_CFG;
$pagetitle .= 'ItemStats ' . _BC_DELIM . ' Update All Items';
include (BASEDIR . 'header.php');
openTable();

require_once($item_stats_dir . 'version.php');
require_once($item_stats_dir . 'check_maj.php');

echo '<table class="forumline" cellspacing="1" border="0">
	<tr>
		<td class="cat">&nbsp;&nbsp;<a class="cattitle" href="' . getlink($module_name) . '">About</a>&nbsp;&nbsp;</td>
		<td class="cat">&nbsp;&nbsp;<a class="cattitle" href="' . getlink('&amp;file=view_cache') . '">View Cache</a>&nbsp;&nbsp;</td>
	</tr>
</table>
<br />';

if (!is_admin()){ die("You are not allowed to access this feature!"); }
include_once(dirname(__FILE__) . '/itemstats.php');
include_once(dirname(__FILE__) . '/config.php');
include_once(dirname(__FILE__) . '/includes/sqlhelper.php');

// amount of items to update before refreshing the status
$step = $MAIN_CFG['item_stats']['number_per_update'];

if (isset($_GET['start']) && is_numeric($_GET['start']) && $_GET['start'] > 0) {	
	$begin = intval($_GET['start']);
} else {
	$begin = 0;
}

// open db connection
$sqlhelper = new SqlHelper(dbhost, dbname, dbuser, dbpass);
if (!$sqlhelper->connected) {
	echo "Could not connect to the database.";
	die();
}

if (isset($_GET['do'])) {
	//
	// update $step amount of items starting at $start/begin
	//
	$sql = 'SELECT item_name FROM ' . item_cache_table . " LIMIT $begin, $step";
	$result = $sqlhelper->query($sql);

	while ($row = $sqlhelper->fetch_record($result)) {
		$item_stats = new ItemStats();
		$item_stats->updateItem($row['item_name']);
	}
	
	$sqlhelper->free_result($result);

	// set the start of the next batch of items to update
	$begin += $step;
	
	// redirect to show status
	url_redirect(getlink('&amp;file=updateallitems&amp;start='.$begin));
} else {
	//
	// show updating status
	//
	$total = 0;
	// get the total amount of items to update
	$sql = 'SELECT COUNT(*) as total FROM ' . item_cache_table;
	$result = $sqlhelper->query($sql);

	if ( $row = $sqlhelper->fetch_record($result) ) {
		$total = $row['total'];
	}	
	
	$sqlhelper->free_result($result);

	// calculate at what percentage we are
	if ($begin >= $total) {
		$progress = 100;
		$begin = $total;
	} else {
		$progress = ceil(($begin / $total) * 100);
	}
	
	// if we havent updated all items, update the next batch of items
	if ($begin < $total) {
		url_refresh(getlink('&amp;file=updateallitems&amp;do&amp;start='.$begin), 0);
	} 

	// output status
	echo '<html>';
	echo '<head>';
	echo "<title>Itemstats Tooltips - $progress</title>";
	echo '</head>';
	echo '<body>';
	echo '!!! DO NOT HIT REFRESH OR LEAVE THIS PAGE UNTIL UPDATING IS COMPLETE !!!<br /><br /><br />';
	echo "Updating itemstats tooltips: $begin/$total ($progress%)";
	echo '</body>';
	echo '</html>';	
	
}

// close the db connection
$sqlhelper->close();

?>